@@ -3,4 +3,10 @@
 """Biomappings Python package."""
 
 from .graph import get_false_graph, get_predictions_graph, get_true_graph  # noqa:F401
-from .resources import MappingTuple, PredictionTuple, load_false_mappings, load_mappings, load_predictions  # noqa:F401
+from .resources import (  # noqa:F401
+    MappingTuple,
+    PredictionTuple,
+    load_false_mappings,
+    load_mappings,
+    load_predictions,
+)
